@@ -1,9 +1,9 @@
 from .event import Event
-from .create import CreateEvent, CreateBranchEvent, CreateTagEvent
+from .create import CreateBranchEvent, CreateEvent, CreateTagEvent
 from .issue_comment import (
-    IssueCommentEvent,
     IssueCommentCreatedEvent,
-    IssueCommentEditedEvent,
     IssueCommentDeletedEvent,
+    IssueCommentEditedEvent,
+    IssueCommentEvent,
 )
 from .release import ReleaseCreatedEvent, ReleaseReleasedEvent
